@@ -4,7 +4,7 @@ extends 'App::SD::Record';
 use Params::Validate qw/validate/;
 
 use constant collection_class => 'App::SD::Collection::Attachment';
-has type => ( default => 'attachment');
+has '+type' => ( default => 'attachment');
 
 
 sub _default_summary_format { '%s,$luid | %s,name | %s,content_type'}
